@@ -8,8 +8,9 @@ try:
     from urllib.request import Request, urlopen
     from urllib.parse import urlencode
     from html.parser import HTMLParser
+    from urllib.error import URLError
 except:
-    from urllib2 import Request, urlopen
+    from urllib2 import Request, urlopen, URLError
     from urllib import urlencode
     from HTMLParser import HTMLParser
 
@@ -22,7 +23,10 @@ def get(url, params=None):
         url += '?' + urlencode(params)
     request = Request(url)
     request.add_header('Cache-Control', 'no-cache')
-    response = urlopen(request)
+    try:
+        response = urlopen(request)
+    except URLError:
+        sys.exit(1)
     result = response.read()
     if type(result) is not str:
         return result.decode()
@@ -38,8 +42,11 @@ def search(keywords, offset, limit):
         sys.exit(1)
     else:
         print_result(response['responseData']['results'])
-        print_pager(response['responseData']['cursor']['resultCount'],
-                    offset, limit)
+        if 'resultCount' in response['responseData']['cursor']:
+            print_pager(response['responseData']['cursor']['resultCount'],
+                        offset, limit)
+        else:
+            print_not_found()
 
 
 class Format:
@@ -98,6 +105,10 @@ def print_pager(total, offset, limit):
                        (offset + 1, offset + limit, total)))
 
 
+def print_not_found():
+    print(pager.format("\nNothing Found\n"))
+
+
 def get_proxy_setting():
     proxy = os.getenv('SOCKS_SERVER', os.getenv('socks_server'))
     if proxy:
